Learn R Programming

TCIApathfinder (version 1.0.6)

get_body_part_names: Get body part names

Description

Get body part names

Usage

get_body_part_names(collection = NULL, modality = NULL)

Arguments

collection

TCIA collection name. If collection is NULL, body part names from all collections will be returned. To get a list of available collection names, call get_collection_names.

modality

Modality name. If modality is NULL, body part names from all modalities will be returned. To get a list of available modality names, call get_modality_names or see DICOM Modality Abbreviations.

Value

List containing elements:

  • body_parts: character vector of body part names

  • content: parsed API response content

  • response: API response

See Also

get_collection_names, get_modality_names, DICOM Modality Abbreviations, TCIA REST API Usage Guide, TCIA API object definitions

Examples

Run this code
# NOT RUN {
get_body_part_names()
get_body_part_names(collection = "TCGA-BRCA")
get_body_part_names(modality = "MR")
get_body_part_names(collection = "TCGA-BRCA", modality = "MR")
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab