Learn R Programming

TCIApathfinder (version 1.0.6)

get_manufacturer_names: Get manufacturer names

Description

Get manufacturer names

Usage

get_manufacturer_names(collection = NULL, modality = NULL,
  body_part = NULL)

Arguments

collection

TCIA collection name. If collection is NULL, manufacturer names from all collections will be returned. To get a list of available collection names, call get_collection_names.

modality

Modality name. If modality is NULL, manufacturer names for all modalities will be returned. To get a list of available modality names, call get_modality_names or see DICOM Modality Abbreviations.

body_part

Body part name. If body_part is NULL, manufacturer names for all body parts will be returned. To get a list of available body part names, call get_body_part_names.

Value

List containing elements:

  • manufacturer_names: character vector of manufacturer names

  • content: parsed API response content

  • response: API response

See Also

get_collection_names, get_modality_names, get_body_part_names, DICOM Modality Abbreviations, TCIA REST API Usage Guide, TCIA API object definitions

Examples

Run this code
# NOT RUN {
get_manufacturer_names()
get_manufacturer_names(collection = "TCGA-BRCA")
get_manufacturer_names(collection = "TCGA-BRCA", modality = "MR", body_part = "BREAST")
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab