Learn R Programming

TCIApathfinder (version 1.0.6)

get_new_patients_in_collection: Get IDs of patients that have been added to a collection since a specified date

Description

Get IDs of patients that have been added to a collection since a specified date

Usage

get_new_patients_in_collection(collection, date)

Arguments

collection

TCIA collection name. To get a list of available collection names, call get_collection_names.

date

Date in format "YYYY-MM-DD"

Value

List containing elements:

  • patient_ids: Patient IDs

  • content: parsed API response content

  • response: API response

See Also

get_collection_names, TCIA REST API Usage Guide, TCIA API object definitions

Examples

Run this code
# NOT RUN {
get_new_patients_in_collection("TCGA-BRCA", "2014-01-01")
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab