Learn R Programming

TCIApathfinder (version 1.0.6)

get_new_studies_in_collection: Get studies that have been added to a collection and optionally to a patient since a specified date

Description

Get studies that have been added to a collection and optionally to a patient since a specified date

Usage

get_new_studies_in_collection(collection, date, patient_id = NULL)

Arguments

collection

TCIA collection name. To get a list of available collection names, call get_collection_names.

date

Date in format "YYYY-MM-DD"

patient_id

Patient ID. To get a list of available patient IDs, call get_patient_info. If patient_id is NULL, relevant studies for all patients in the collection will be returned.

Value

List containing elements:

  • studies: Data frame of collection, patient ID, and study instance UID

  • content: parsed API response content

  • response: API response

See Also

get_collection_names, get_patient_info, TCIA REST API Usage Guide, TCIA API object definitions

Examples

Run this code
# NOT RUN {
get_new_studies_in_collection("TCGA-BRCA", "2014-01-01")
get_new_studies_in_collection("TCGA-BRCA", "2014-01-01", "TCGA-OL-A66O")
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab