Learn R Programming

TCIApathfinder (version 1.0.6)

get_patient_studies: Get patient study information

Description

Get patient study information

Usage

get_patient_studies(collection = NULL, patient_id = NULL,
  study_instance_uid = NULL)

Arguments

collection

TCIA collection name. To get a list of available collection names, call get_collection_names. If collection is NULL, information for all relevant collections will be returned.

patient_id

Patient ID. To get a list of available patient IDs, call get_patient_info. If patient_id is NULL, information for all relevant patients will be returned.

study_instance_uid

Study instance UID. If study_instance_uid is NULL, information for all relevant study instance UIDs will be returned. To get available study instance UIDs, call get_studies_in_collection, get_patient_studies, or get_new_studies_in_collection.

Value

List containing elements:

  • patient_studies: Data frame with columns representing the contents of a PatientStudy object as described in TCIA API Return Values

  • content: parsed API response content

  • response: API response

See Also

get_collection_names, get_patient_info, get_studies_in_collection, get_patient_studies, get_new_studies_in_collection, TCIA REST API Usage Guide, TCIA API object definitions

Examples

Run this code
# NOT RUN {
get_patient_studies()
get_patient_studies(collection = "TCGA-BRCA")
get_patient_studies(patient_id = "TCGA-OL-A6VO")
get_patient_studies(patient_id = "TCGA-OL-A5DA",
     study_instance_uid = "1.3.6.1.4.1.14519.5.2.1.5382.4002.104582989590517557856962159716")
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab