Learn R Programming

TCIApathfinder (version 1.0.6)

get_patients_by_modality: Get patient IDs given a collection name and modality

Description

Get patient IDs given a collection name and modality

Usage

get_patients_by_modality(collection, modality)

Arguments

collection

TCIA collection name. To get a list of available collection names, call get_collection_names.

modality

Modality name. To get a list of available modality names, call get_modality_names or see DICOM Modality Abbreviations.

Value

List containing elements:

  • patient_ids: Patient IDs

  • content: parsed API response content

  • response: API response

See Also

get_collection_names, get_modality_names, DICOM Modality Abbreviations, TCIA REST API Usage Guide, TCIA API object definitions

Examples

Run this code
# NOT RUN {
get_patients_by_modality("TCGA-BRCA", "MR")
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab