Get image series information
get_series_info(collection = NULL, patient_id = NULL,
study_instance_uid = NULL, series_instance_uid = NULL,
modality = NULL, body_part_examined = NULL,
manufacturer_model_name = NULL, manufacturer = NULL)TCIA collection name. To get a list of available collection
names, call get_collection_names. If collection is NULL, information
for all relevant collections will be returned.
Patient ID. To get a list of available patient IDs, call get_patient_info.
If patient_id is NULL, information for all relevant patients will be returned.
Study instance UID. If study_instance_uid is NULL, information
for all relevant study instance UIDs will be returned. To get available study instance UIDs, call get_studies_in_collection,
get_patient_studies, or get_new_studies_in_collection.
Series instance UID. To get a list of available series instance UIDs, call
this function leaving out parameter series_instance_uid. If series_instance_uid is NULL,
information for all relevant series will be returned.
Modality name. To get a list of available modality names, call get_modality_names
or see DICOM Modality Abbreviations.
If modality is NULL, information for all relevant modalities will be returned.
Body part name. To get a list of available body part names, call
get_body_part_names. If body_part_examined is NULL, information
for all relevant body parts will be returned. IMPORTANT: a bug in this query key has been observed in the TCIA API.
If queries using this key return zero results, try removing this parameter.
Manufacturer model name. To get a list of available model names, call
this function leaving out parameter manufacturer_model_name. If manufacturer_model_name is NULL,
information for all relevant model names will be returned.
Manufacturer name. To get a list of available manufacturer names, call
get_manufacturer_names. If manufacturer is NULL,
information for all relevant manufacturers will be returned.
List containing elements:
series: Data frame with columns representing the contents of a Series object
as described in TCIA API Return Values
content: parsed API response content
response: API response
get_collection_names,
get_patient_info,
get_studies_in_collection,
get_patient_studies,
get_new_studies_in_collection,
get_modality_names,
get_body_part_names,
get_manufacturer_names,
TCIA REST API Usage Guide,
TCIA API object definitions
# NOT RUN {
get_series_info()
get_series_info(collection = "TCGA-BRCA")
get_series_info(patient_id = "TCGA-OL-A6VO")
get_series_info(modality = "MR", manufacturer = "GE MEDICAL SYSTEMS")
# }
# NOT RUN {
# }
Run the code above in your browser using DataLab