powered by
Get IDs of patients that have been added to a collection since a specified date
get_new_patients_in_collection(collection, date)
TCIA collection name. To get a list of available collection names, call get_collection_names.
get_collection_names
Date in format "YYYY-MM-DD"
List containing elements:
patient_ids: Patient IDs
patient_ids
content: parsed API response content
content
response: API response
response
get_collection_names, TCIA REST API Usage Guide, TCIA API object definitions
# NOT RUN { get_new_patients_in_collection("TCGA-BRCA", "2014-01-01") # } # NOT RUN { # }
Run the code above in your browser using DataLab