powered by
Get patient IDs given a collection name and modality
get_patients_by_modality(collection, modality)
TCIA collection name. To get a list of available collection names, call get_collection_names.
get_collection_names
Modality name. To get a list of available modality names, call get_modality_names or see DICOM Modality Abbreviations.
get_modality_names
List containing elements:
patient_ids: Patient IDs
patient_ids
content: parsed API response content
content
response: API response
response
get_collection_names, get_modality_names, DICOM Modality Abbreviations, TCIA REST API Usage Guide, TCIA API object definitions
# NOT RUN { get_patients_by_modality("TCGA-BRCA", "MR") # } # NOT RUN { # }
Run the code above in your browser using DataLab